@@ -441,6 +441,7 @@ def _wham(**args):
 @arg("--python-exec", help="python executable", default="")
 @arg("-S", "--sockname", help="screen sockname", default="jupyter-server")
 @arg("--no-screen", help="do not run screen", action="store_true")
+@arg("--keep-ld-library-path", help="propagate LD_LIBRARY_PATH through screen", action="store_true")
 @arg("--detach", help="detach screen", action="store_true")
 def _jrun(**kargs):
     """
@@ -542,7 +543,8 @@ def _pip_upgrade_all(**kargs):
 @arg("-u","--update", help="url of the message to be updated")
 @arg("-d","--delete", help="url of the message to be deleted")
 @endgroup
-@arg("-t","--title", help="url of the message to be deleted")
+@arg("-f","--file", help="path to a file to be uploaded (incompatible with -u and -d)")
+@arg("-t","--title", help="title of the message")
 @arg("--type", help="'plain_text' or 'mrkdwn'", default='mrkdwn')
 @arg("--token", help="token (check ~/.bussilabrc by default")
 def _notify(**kargs):
